# pyquats

Python implementation of quaternions is presented. 
The code is written with Python 2.7 and Python 3.7.

## Modules

* quats - Quat class
* numpyquats - Quat class using numpy (slow)
* qmath - mathematical functions for quaternions
[exp(q), log(c), sin(q), cos(q), sinh(q), cosh(q)]
* qtools - rotations, random unit quaternions

## References

[1] http://en.wikipedia.org/wiki/Quaternion

EOF
